Index: src/wp-admin/admin-header.php
===================================================================
--- src/wp-admin/admin-header.php	(revision 27371)
+++ src/wp-admin/admin-header.php	(working copy)
@@ -65,7 +65,8 @@
 	adminpage = '<?php echo $admin_body_class; ?>',
 	thousandsSeparator = '<?php echo addslashes( $wp_locale->number_format['thousands_sep'] ); ?>',
 	decimalPoint = '<?php echo addslashes( $wp_locale->number_format['decimal_point'] ); ?>',
-	isRtl = <?php echo (int) is_rtl(); ?>;
+	isRtl = <?php echo (int) is_rtl(); ?>,
+	isAdmin = true;
 </script>
 <meta name="viewport" content="width=device-width,initial-scale=1.0">
 <?php
Index: src/wp-admin/js/post.js
===================================================================
--- src/wp-admin/js/post.js	(revision 27371)
+++ src/wp-admin/js/post.js	(working copy)
@@ -1,5 +1,5 @@
 /* global postL10n, ajaxurl, wpAjax, setPostThumbnailL10n, postboxes, pagenow, tinymce, alert, deleteUserSetting */
 /* global theList:true, theExtraList:true, getUserSetting, setUserSetting */
 
 var tagBox, commentsBox, WPSetThumbnailHTML, WPSetThumbnailID, WPRemoveThumbnail, wptitlehint, makeSlugeditClickable, editPermalink;
 // Back-compat: prevent fatal errors
@@ -1065,7 +1065,7 @@
 		});
 	}
 
-	if ( ! ( 'ontouchstart' in window ) ) {
+	if ( ! ( 'ontouchstart' in window ) && isAdmin ) {
 		// When scrolling with mouse wheel or trackpad inside the Text editor, don't scroll the whole window
 		$content = $('#content').on( 'onwheel' in $document[0] ? 'wheel.text-editor-scroll' : 'mousewheel.text-editor-scroll', function( event ) {
 			var delta, top,
@@ -1,5 +1,5 @@
 /* global postL10n, ajaxurl, wpAjax, setPostThumbnailL10n, postboxes, pagenow, tinymce, alert, deleteUserSetting */
-/* global theList:true, theExtraList:true, getUserSetting, setUserSetting */
+/* global theList:true, theExtraList:true, getUserSetting, setUserSetting, isAdmin */
 
 var tagBox, commentsBox, WPSetThumbnailHTML, WPSetThumbnailID, WPRemoveThumbnail, wptitlehint, makeSlugeditClickable, editPermalink;
